@@ -3,13 +3,13 @@ import below
 ---------------------------
 """
 import os,sys
-from FastCNN.prx.GongDaProxy import predictPicture
+
 
 debug = False
 if os.path.exists("./debug"):
-    sys.path.insert(os.path.abspath("../"))
+    sys.path.insert(0,os.path.abspath("../../"))
     debug = True
-
+from FastCNN.prx.GongDaProxy import predictPicture
 """
 function below
 --------------------------
@@ -46,12 +46,14 @@ def callPredictPicture():
     modelpath = getArg()
     picturepath = getArg()
     
-    if modelpath && picturepath:
-        rtn = predictPicture(modelpath,picturepath)
-        print(rtn)
+    if modelpath:
+        if picturepath:
+            rtn = predictPicture(modelpath,picturepath)
+            print(rtn)
+            return
         
-    else:
-        print("call predict error")
+    
+    print("call predict error")
 
 """
 main below
