@@ -1,10 +1,11 @@
-
+import os
+os.environ["TF_CPP_MIN_LOG_LEVEL"]='3'
 import tensorflow as tf
 from tensorflow.keras import Model
 from tensorflow.keras.layers import Layer
 from PIL import Image
 import numpy as np
-import os
+
 import random
 import matplotlib.pyplot as plt
 import shutil
@@ -14,7 +15,8 @@ from tensorflow.keras.layers import Conv2D, BatchNormalization, Activation, MaxP
 
 trainpath = r"./train/"
 testpath = r"./test/"
-os.environ[“TF_CPP_MIN_LOG_LEVEL”]='3'
+
+
 np.set_printoptions(threshold=np.inf)
 
 from tensorflow.compat.v1 import ConfigProto
